@@ -47,7 +47,7 @@ from .namespaces.workspace.table import Table
 
 # TODO this is a manual task, to keep in sync with pyproject.toml
 # could/should be automated to keep in sync
-__version__ = "0.8.0"
+__version__ = "0.10.1"
 
 PERSONAL_API_KEY_LOCATION = "~/.config/xata/key"
 DEFAULT_DATA_PLANE_DOMAIN = "xata.sh"
@@ -133,6 +133,7 @@ class XataClient:
         self.domain_core = domain_core
         self.domain_workspace = domain_workspace
 
+        # init default headers
         self.headers = {
             "authorization": f"Bearer {self.api_key}",
             "user-agent": f"xataio/xata-py:{__version__}",
@@ -141,6 +142,18 @@ class XataClient:
             "x-xata-agent": f"client=PY_SDK;version={__version__};",
         }
 
+        # init namespaces
+        self._authentication = Authentication(self)
+        self._branch = Branch(self)
+        self._search_and_filter = Search_and_filter(self)
+        self._databases = Databases(self)
+        self._invites = Invites(self)
+        self._migrations = Migrations(self)
+        self._records = Records(self)
+        self._table = Table(self)
+        self._users = Users(self)
+        self._workspaces = Workspaces(self)
+
     def get_config(self) -> dict:
         """
         Get the configuration
@@ -220,7 +233,7 @@ class XataClient:
 
         self.ensure_config_read()
         if self.config is not None and self.config.get("databaseURL"):
-            workspaceID, region, _, _ = self._parse_database_url(self.config.get("databaseURL"))
+            workspaceID, region, _, _, _ = self._parse_database_url(self.config.get("databaseURL"))
             return workspaceID, region, "config"
         raise Exception(
             f"No workspace ID found. Searched in `XATA_WORKSPACE_ID` env, "
@@ -230,7 +243,7 @@ class XataClient:
     def get_database_name_if_configured(self) -> str:
         self.ensure_config_read()
         if self.config is not None and self.config.get("databaseURL"):
-            _, _, db_name, _ = self._parse_database_url(self.config.get("databaseURL"))
+            _, _, db_name, _, _ = self._parse_database_url(self.config.get("databaseURL"))
             return db_name
         return None
 
@@ -747,114 +760,79 @@ class XataClient:
             raise BadRequestException(result.status_code, result.json()["message"])
         return result.json()
 
-    # --------------------------------------------------- #
-    #
-    # Namespace: CORE
-    #
-    # --------------------------------------------------- #
-
     def authentication(self) -> Authentication:
         """
         Authentication Namespace
-        scope: core
         :return Authentication
         """
-        if "authentication" not in self.namespaces:
-            self.namespaces["authentication"] = Authentication(self)
-        return self.namespaces["authentication"]
+        return self._authentication
 
     def databases(self) -> Databases:
         """
         Databases Namespace
-        scope: core
         :return Databases
         """
-        if "databases" not in self.namespaces:
-            self.namespaces["databases"] = Databases(self)
-        return self.namespaces["databases"]
+        return self._databases
 
     def invites(self) -> Invites:
         """
         Invites Namespace
-        scope: core
         :return Invites
         """
-        if "invites" not in self.namespaces:
-            self.namespaces["invites"] = Invites(self)
-        return self.namespaces["invites"]
+        return self._invites
 
     def users(self) -> Users:
         """
         Users Namespace
-        scope: core
         :return Users
         """
-        if "users" not in self.namespaces:
-            self.namespaces["users"] = Users(self)
-        return self.namespaces["users"]
+        return self._users
 
     def workspaces(self) -> Workspaces:
         """
         Workspaces Namespace
-        scope: core
         :return Workspaces
         """
-        if "workspaces" not in self.namespaces:
-            self.namespaces["workspaces"] = Workspaces(self)
-        return self.namespaces["workspaces"]
-
-    # --------------------------------------------------- #
-    #
-    # Namespace: WORKSPACE
-    #
-    # --------------------------------------------------- #
+        return self._workspaces
 
     def branch(self) -> Branch:
         """
         Branch Namespace
-        scope: workspace
         :return Branch
         """
-        if "branch" not in self.namespaces:
-            self.namespaces["branch"] = Branch(self)
-        return self.namespaces["branch"]
+        return self._branch
 
     def migrations(self) -> Migrations:
         """
         Migrations Namespace
-        scope: workspace
         :return Migrations
         """
-        if "migrations" not in self.namespaces:
-            self.namespaces["migrations"] = Migrations(self)
-        return self.namespaces["migrations"]
+        return self._migrations
 
     def records(self) -> Records:
         """
         Records Namespace
-        scope: workspace
         :return Records
         """
-        if "records" not in self.namespaces:
-            self.namespaces["records"] = Records(self)
-        return self.namespaces["records"]
+        return self._records
 
     def search_and_filter(self) -> Search_and_filter:
         """
         Search_and_Filter Namespace
-        scope: workspace
         :return Search_and_filter
         """
-        if "search_and_filter" not in self.namespaces:
-            self.namespaces["search_and_filter"] = Search_and_filter(self)
-        return self.namespaces["search_and_filter"]
+        return self._search_and_filter
+
+    def data(self) -> Search_and_filter:
+        """
+        Shorter alias for Search_and_Filter
+        :return Search_and_filter
+        """
+        return self._search_and_filter
 
     def table(self) -> Table:
         """
         Table Namespace
-        scope: workspace
         :return Table
         """
-        if "table" not in self.namespaces:
-            self.namespaces["table"] = Table(self)
-        return self.namespaces["table"]
+        return self._table
