@@ -21,7 +21,6 @@
 # Search_and_filter
 # APIs for searching, querying, filtering, and aggregating records.
 # Specification: workspace:v1.0
-# Base URL: https://{workspaceId}.{regionId}.xata.sh
 # ------------------------------------------------------- #
 
 from requests import Response
@@ -31,16 +30,9 @@ from xata.namespace import Namespace
 
 class Search_and_filter(Namespace):
 
-    base_url = "https://{workspaceId}.{regionId}.xata.sh"
     scope = "workspace"
 
-    def queryTable(
-        self,
-        table_name: str,
-        payload: dict,
-        db_name: str = None,
-        branch_name: str = None,
-    ) -> Response:
+    def queryTable(self, table_name: str, payload: dict, db_name: str = None, branch_name: str = None) -> Response:
         """
         The Query Table API can be used to retrieve all records in a table.  The API support
         filtering, sorting, selecting a subset of columns, and pagination.  The overall structure
@@ -159,15 +151,16 @@ class Search_and_filter(Namespace):
         } } ```  or descendently:  ```json POST /db/demo:main/tables/table/query {   "sort": {
         "index": "desc"   } } ```  Sorting by multiple fields:  ```json POST
         /db/demo:main/tables/table/query {   "sort": [     {       "index": "desc"     },     {
-        "createdAt": "desc"     }   ] } ```  ### Pagination  We offer cursor pagination and offset
-        pagination.  For queries that are expected to return more than 1000 records, cursor
-        pagination is needed in order to retrieve all of their results.  The offset pagination
-        method is limited to 1000 records.  Example of size + offset pagination:  ```json POST
-        /db/demo:main/tables/table/query {   "page": {     "size": 100,     "offset": 200   } }
-        ```  The `page.size` parameter represents the maximum number of records returned by this
-        query.  It has a default value of 20 and a maximum value of 200. The `page.offset`
-        parameter represents the number of matching records to skip.  It has a default value of 0
-        and a maximum value of 800.  Example of cursor pagination:  ```json POST
+        "createdAt": "desc"     }   ] } ```  It is also possible to sort results randomly:
+        ```json POST /db/demo:main/tables/table/query {   "sort": {     "*": "random"   } } ```
+        Note that a random sort does not apply to a specific column, hence the special column name
+        `"*"`.  A random sort can be combined with an ascending or descending sort on a specific
+        column:  ```json POST /db/demo:main/tables/table/query {   "sort": [     {       "name":
+        "desc"     },     {       "*": "random"     }   ] } ```  This will sort on the `name`
+        column, breaking ties randomly.  ### Pagination  We offer cursor pagination and offset
+        pagination.  The cursor pagination method can be used for sequential scrolling with
+        unrestricted depth.  The offset pagination can be used to skip pages and is limited to
+        1000 records.  Example of cursor pagination:  ```json POST
         /db/demo:main/tables/table/query {   "page": {
         "after":"fMoxCsIwFIDh3WP8c4amDai5hO5SJCRNfaVSeC9b6d1FD"   } } ```  In the above example,
         the value of the `page.after` parameter is the cursor returned by the previous query.  A
@@ -192,22 +185,33 @@ class Search_and_filter(Namespace):
         `columns`, `sort` , and `page.size` configuration will be encoded with the cursor.  The
         pagination request will be invalid if `filter` or `sort` is set.  The columns returned and
         page size can be changed anytime by passing the `columns` or `page.size` settings to the
-        next query.  **Special cursors:**  - `page.after=end`: Result points past the last entry.
-        The list of records   returned is empty, but `page.meta.cursor` will include a cursor that
-        can be   used to "tail" the table from the end waiting for new data to be inserted.  -
-        `page.before=end`: This cursor returns the last page.  - `page.start=<cursor>`: Start at
-        the beginning of the result set of the <cursor> query.  This is equivalent to querying the
-        first page without a cursor but applying `filter` and `sort` . Yet the `page.start`
-        cursor can be convenient at times as user code does not need to remember the   filter,
-        sort, columns or page size configuration.  All these information are   read from the
-        cursor.  - `page.end=<cursor>`: Move to the end of the result set of the <cursor> query.
-        This is equivalent to querying the   last page with `page.before=end`, `filter`, and
-        `sort` . Yet the   `page.end` cursor can be more convenient at times as user code does not
-        need to remember the filter, sort, columns or page size configuration.  All   these
-        information are read from the cursor.  When using special cursors like `page.after="end"`
-        or `page.before="end"`, we still allow `filter` and `sort` to be set.  Example of getting
-        the last page:  ```json POST /db/demo:main/tables/table/query {   "page": {     "size":
-        10,     "before": "end"   } } ```
+        next query.  In the following example of size + offset pagination we retrieve the third
+        page of up to 100 results:  ```json POST /db/demo:main/tables/table/query {   "page": {
+        "size": 100,     "offset": 200   } } ```  The `page.size` parameter represents the maximum
+        number of records returned by this query.  It has a default value of 20 and a maximum
+        value of 200. The `page.offset` parameter represents the number of matching records to
+        skip.  It has a default value of 0 and a maximum value of 800.  Cursor pagination also
+        works in combination with offset pagination.  For example, starting from a specific cursor
+        position, using a page size of 200 and an offset of 800, you can skip up to 5 pages of 200
+        records forwards or backwards from the cursor's position:  ```json POST
+        /db/demo:main/tables/table/query {   "page": {     "size": 200,     "offset": 800,
+        "after": "fMoxCsIwFIDh3WP8c4amDai5hO5SJCRNfaVSeC9b6d1FD"   } } ```  **Special cursors:**
+        - `page.after=end`: Result points past the last entry.  The list of records   returned is
+        empty, but `page.meta.cursor` will include a cursor that can be   used to "tail" the table
+        from the end waiting for new data to be inserted.  - `page.before=end`: This cursor
+        returns the last page.  - `page.start=<cursor>`: Start at the beginning of the result set
+        of the <cursor> query.  This is equivalent to querying the   first page without a cursor
+        but applying `filter` and `sort` . Yet the `page.start`   cursor can be convenient at
+        times as user code does not need to remember the   filter, sort, columns or page size
+        configuration.  All these information are   read from the cursor.  - `page.end=<cursor>`:
+        Move to the end of the result set of the <cursor> query.  This is equivalent to querying
+        the   last page with `page.before=end`, `filter`, and `sort` . Yet the   `page.end` cursor
+        can be more convenient at times as user code does not   need to remember the filter, sort,
+        columns or page size configuration.  All   these information are read from the cursor.
+        When using special cursors like `page.after="end"` or `page.before="end"`, we still allow
+        `filter` and `sort` to be set.  Example of getting the last page:  ```json POST
+        /db/demo:main/tables/table/query {   "page": {     "size": 10,     "before": "end"   } }
+        ```
 
         Path: /db/{db_branch_name}/tables/{table_name}/query
         Method: POST
@@ -255,13 +259,7 @@ class Search_and_filter(Namespace):
         headers = {"content-type": "application/json"}
         return self.request("POST", url_path, headers, payload)
 
-    def searchTable(
-        self,
-        table_name: str,
-        payload: dict,
-        db_name: str = None,
-        branch_name: str = None,
-    ) -> Response:
+    def searchTable(self, table_name: str, payload: dict, db_name: str = None, branch_name: str = None) -> Response:
         """
         Run a free text search operation in a particular table.  The endpoint accepts a `query`
         parameter that is used for the free text search and a set of structured filters (via the
@@ -293,11 +291,7 @@ class Search_and_filter(Namespace):
         return self.request("POST", url_path, headers, payload)
 
     def vectorSearchTable(
-        self,
-        table_name: str,
-        payload: dict,
-        db_name: str = None,
-        branch_name: str = None,
+        self, table_name: str, payload: dict, db_name: str = None, branch_name: str = None
     ) -> Response:
         """
         This endpoint can be used to perform vector-based similarity searches in a table.  It can
@@ -368,13 +362,7 @@ class Search_and_filter(Namespace):
         }
         return self.request("POST", url_path, headers, payload)
 
-    def summarizeTable(
-        self,
-        table_name: str,
-        payload: dict,
-        db_name: str = None,
-        branch_name: str = None,
-    ) -> Response:
+    def summarizeTable(self, table_name: str, payload: dict, db_name: str = None, branch_name: str = None) -> Response:
         """
         This endpoint allows you to (optionally) define groups, and then to run calculations on
         the values in each group.  This is most helpful when  you'd like to understand the data
@@ -431,13 +419,7 @@ class Search_and_filter(Namespace):
         headers = {"content-type": "application/json"}
         return self.request("POST", url_path, headers, payload)
 
-    def aggregateTable(
-        self,
-        table_name: str,
-        payload: dict,
-        db_name: str = None,
-        branch_name: str = None,
-    ) -> Response:
+    def aggregateTable(self, table_name: str, payload: dict, db_name: str = None, branch_name: str = None) -> Response:
         """
         This endpoint allows you to run aggregations (analytics) on the data from one table.
         While the summary endpoint is served from a transactional store and the results are
